@@ -49,6 +49,7 @@ class NotificationMessage::Private : public QSharedData
       uid = other.uid;
       remoteId = other.remoteId;
       resource = other.resource;
+      destResource = other.destResource;
       parentCollection = other.parentCollection;
       parentDestCollection = other.parentDestCollection;
       mimeType = other.mimeType;
@@ -62,6 +63,7 @@ class NotificationMessage::Private : public QSharedData
           && sessionId == other.sessionId
           && remoteId == other.remoteId
           && resource == other.resource
+          && destResource == other.destResource
           && parentCollection == other.parentCollection
           && parentDestCollection == other.parentDestCollection
           && mimeType == other.mimeType;
@@ -78,6 +80,7 @@ class NotificationMessage::Private : public QSharedData
     Id uid;
     QString remoteId;
     QByteArray resource;
+    QByteArray destResource;
     Id parentCollection;
     Id parentDestCollection;
     QString mimeType;
@@ -197,6 +200,16 @@ void NotificationMessage::setParentDestCollection( Id parent )
   d->parentDestCollection = parent;
 }
 
+void NotificationMessage::setDestinationResource( const QByteArray &destResource )
+{
+  d->destResource = destResource;
+}
+
+QByteArray NotificationMessage::destinationResource() const
+{
+  return d->destResource;
+}
+
 QString NotificationMessage::mimeType() const
 {
   return d->mimeType;
@@ -278,6 +291,12 @@ QString NotificationMessage::toString() const
 }
 
 void NotificationMessage::appendAndCompress( NotificationMessage::List &list, const NotificationMessage &msg )
+{
+  bool appended;
+  appendAndCompress( list, msg, &appended );
+}
+
+void NotificationMessage::appendAndCompress( NotificationMessage::List &list, const NotificationMessage &msg, bool *appended )
 {
   // fast-path for stuff that is not considered during O(n) compression below
   if ( msg.operation() != Add && msg.operation() != Link && msg.operation() != Unlink && msg.operation() != Subscribe && msg.operation() != Unsubscribe && msg.operation() != Move ) {
@@ -287,10 +306,12 @@ void NotificationMessage::appendAndCompress( NotificationMessage::List &list, co
         // same operation: merge changed parts and drop the new one
         if ( msg.operation() == (*it).operation() ) {
           (*it).setItemParts( (*it).itemParts() + msg.itemParts() );
+          *appended = false;
           return;
         }
         // new one is a modification, the existing one not, so drop the new one
         else if ( msg.operation() == Modify ) {
+          *appended = false;
           return;
         }
         // new on is a deletion, erase the existing modification ones (and keep going, in case there are more)
@@ -307,6 +328,7 @@ void NotificationMessage::appendAndCompress( NotificationMessage::List &list, co
       }
     }
   }
+  *appended = true;
   list.append( msg );
 }
 
@@ -324,8 +346,13 @@ QDBusArgument& operator<<( QDBusArgument &arg, const NotificationMessage &msg )
   arg << msg.mimeType();
 
   QStringList itemParts;
-  foreach ( const QByteArray &itemPart, msg.itemParts() )
-    itemParts.append( QString::fromLatin1( itemPart ) );
+  if ( msg.operation() == NotificationMessage::Move ) {
+    // encode destination resource in parts, as a backward compat hack
+    itemParts.push_back( QString::fromLatin1( msg.destinationResource() ) );
+  } else {
+    foreach ( const QByteArray &itemPart, msg.itemParts() )
+      itemParts.append( QString::fromLatin1( itemPart ) );
+  }
 
   arg << itemParts;
   arg.endStructure();
@@ -361,8 +388,13 @@ const QDBusArgument& operator>>( const QDBusArgument &arg, NotificationMessage &
   arg >> l;
 
   QSet<QByteArray> itemParts;
-  foreach ( const QString &itemPart, l )
-    itemParts.insert( itemPart.toLatin1() );
+  if ( msg.operation() == NotificationMessage::Move && l.size() >= 1 ) {
+    // decode destination resource, which is stored in parts as a backward compat hack
+    msg.setDestinationResource( l.first().toLatin1() );
+  } else {
+    foreach ( const QString &itemPart, l )
+      itemParts.insert( itemPart.toLatin1() );
+  }
 
   msg.setItemParts( itemParts );
   arg.endStructure();
