@@ -29,7 +29,8 @@
 
 #include <config-akonadi.h>
 
-#include "akapplication.h"
+#include <akapplication.h>
+#include <akdbus.h>
 #include "protocol_p.h"
 
 #include "controlmanagerinterface.h"
@@ -46,8 +47,8 @@ static bool startServer()
 {
   //Needed for wince build
   #undef interface
-  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE) )
-       || QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_SERVER_SERVICE) ) ) {
+  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Control) )
+       || QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Server) ) ) {
     qDebug() << "Akonadi is already running.";
     return false;
   }
@@ -57,7 +58,7 @@ static bool startServer()
 
 static bool stopServer()
 {
-  org::freedesktop::Akonadi::ControlManager iface( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE),
+  org::freedesktop::Akonadi::ControlManager iface( AkDBus::serviceName(AkDBus::Control),
                                                    QLatin1String("/ControlManager"),
                                                    QDBusConnection::sessionBus(), 0 );
   if ( !iface.isValid() ) {
@@ -72,10 +73,10 @@ static bool stopServer()
 
 static bool statusServer()
 {
-  bool registered = QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE) );
+  bool registered = QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Control) );
   qDebug( "Akonadi Control: %s", registered ? "running" : "stopped" );
 
-  registered = QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_SERVER_SERVICE) );
+  registered = QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Server) );
   qDebug( "Akonadi Server: %s", registered ? "running" : "stopped" );
 
   registered = QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String("org.kde.nepomuk.services.nepomukqueryservice") );
@@ -106,26 +107,34 @@ static bool statusServer()
 
 int main( int argc, char **argv )
 {
-  AkApplication app( argc, argv );
+  AkCoreApplication app( argc, argv );
   app.setDescription( QLatin1String("Akonadi server manipulation tool\n"
       "Usage: akonadictl [command]\n\n"
       "Commands:\n"
       "  start      : Starts the Akonadi server with all its processes\n"
       "  stop       : Stops the Akonadi server and all its processes cleanly\n"
       "  restart    : Restart Akonadi server with all its processes\n"
-      "  status     : Shows a status overview of the Akonadi server"
+      "  status     : Shows a status overview of the Akonadi server\n"
+      "  vacuum     : Vacuum internal storage (WARNING: needs a lot of time and disk space!)\n"
+      "  fsck       : Check (and attempt to fix) consistency of the internal storage (can take some time)"
   ) );
 
   app.parseCommandLine();
 
-  QString optionsList;
+  QStringList optionsList;
   optionsList.append( QLatin1String( "start" ) );
   optionsList.append( QLatin1String( "stop" ) );
   optionsList.append( QLatin1String( "status" ) );
   optionsList.append( QLatin1String( "restart" ) );
+  optionsList.append( QLatin1String( "vacuum" ) );
+  optionsList.append( QLatin1String( "fsck" ) );
 
+  QStringList arguments = QCoreApplication::instance()->arguments();
 #ifndef _WIN32_WCE
-  const QStringList arguments = app.arguments();
+  if ( AkApplication::hasInstanceIdentifier() ) { // HACK: we should port all of this to boost::program_options...
+    arguments.removeFirst();
+    arguments.removeFirst();
+  }
   if ( arguments.count() != 2 ) {
     app.printUsage();
     return 1;
@@ -134,7 +143,6 @@ int main( int argc, char **argv )
     return 2;
   }
 #else
-    QStringList arguments = app.arguments();
     if (argc > 1) {
       if (strcmp(argv[1],"start") == 0) {
         arguments.append(QLatin1String("start"));
@@ -177,11 +185,16 @@ int main( int argc, char **argv )
 #else
           Sleep(100000);
 #endif
-        } while( QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE) ) );
+        } while( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Control) ) );
         if ( !startServer() )
           return 3;
       }
+  } else if ( arguments[ 1 ] == QLatin1String( "vacuum" ) ) {
+    QDBusInterface iface( AkDBus::serviceName(AkDBus::StorageJanitor), QLatin1String(AKONADI_DBUS_STORAGEJANITOR_PATH) );
+    iface.call( QDBus::NoBlock, QLatin1String( "vacuum" ) );
+  } else if ( arguments[ 1 ] == QLatin1String( "fsck" ) ) {
+    QDBusInterface iface( AkDBus::serviceName(AkDBus::StorageJanitor), QLatin1String(AKONADI_DBUS_STORAGEJANITOR_PATH) );
+    iface.call( QDBus::NoBlock, QLatin1String( "check" ) );
   }
-
   return 0;
 }
