@@ -33,6 +33,10 @@
 #include "resource_manager.h"
 #include "serverinterface.h"
 
+#include <akapplication.h>
+#include <akdbus.h>
+#include <akstandarddirs.h>
+
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDebug>
 #include <QtCore/QDir>
@@ -64,27 +68,31 @@ AgentManager::AgentManager( QObject *parent )
   new AgentManagerInternalAdaptor( this );
   QDBusConnection::sessionBus().registerObject( QLatin1String("/AgentManager"), this );
 
-  connect( QDBusConnection::sessionBus().interface(), SIGNAL( serviceOwnerChanged( const QString&, const QString&, const QString& ) ),
-           this, SLOT( serviceOwnerChanged( const QString&, const QString&, const QString& ) ) );
+  connect( QDBusConnection::sessionBus().interface(), SIGNAL(serviceOwnerChanged(QString,QString,QString)),
+           this, SLOT(serviceOwnerChanged(QString,QString,QString)) );
 
-  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String("org.freedesktop.Akonadi") ) )
+  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Server) ) )
     akFatal() << "akonadiserver already running!";
 
-  const QSettings settings( configPath( false ), QSettings::IniFormat );
+  const QSettings settings( AkStandardDirs::agentConfigFile( Akonadi::XdgBaseDirs::ReadOnly ), QSettings::IniFormat );
   mAgentServerEnabled = settings.value( QLatin1String("AgentServer/Enabled"), enableAgentServerDefault ).toBool();
 
+  QStringList serviceArgs;
+  if ( !AkApplication::instanceIdentifier().isEmpty() )
+    serviceArgs << QLatin1String("--instance") << AkApplication::instanceIdentifier();
+
   mStorageController = new Akonadi::ProcessControl;
-  connect( mStorageController, SIGNAL( unableToStart() ), SLOT( serverFailure() ) );
-  mStorageController->start( QLatin1String("akonadiserver"), QStringList(), Akonadi::ProcessControl::RestartOnCrash );
+  connect( mStorageController, SIGNAL(unableToStart()), SLOT(serverFailure()) );
+  mStorageController->start( QLatin1String("akonadiserver"), serviceArgs, Akonadi::ProcessControl::RestartOnCrash );
 
   if ( mAgentServerEnabled ) {
     mAgentServer = new Akonadi::ProcessControl;
-    connect( mAgentServer, SIGNAL( unableToStart() ), SLOT( agentServerFailure() ) );
-    mAgentServer->start( QLatin1String("akonadi_agent_server"), QStringList(), Akonadi::ProcessControl::RestartOnCrash );
+    connect( mAgentServer, SIGNAL(unableToStart()), SLOT(agentServerFailure()) );
+    mAgentServer->start( QLatin1String("akonadi_agent_server"), serviceArgs, Akonadi::ProcessControl::RestartOnCrash );
   }
 
 #ifndef QT_NO_DEBUG
-  connect( mAgentWatcher, SIGNAL( fileChanged( QString ) ), SLOT( agentExeChanged( QString ) ) );
+  connect( mAgentWatcher, SIGNAL(fileChanged(QString)), SLOT(agentExeChanged(QString)) );
 #endif
 }
 
@@ -108,8 +116,8 @@ void AgentManager::continueStartup()
     QFileSystemWatcher *watcher = new QFileSystemWatcher( this );
     watcher->addPath( path );
 
-    connect( watcher, SIGNAL( directoryChanged( const QString& ) ),
-             this, SLOT( updatePluginInfos() ) );
+    connect( watcher, SIGNAL(directoryChanged(QString)),
+             this, SLOT(updatePluginInfos()) );
   }
 #endif
 
@@ -118,9 +126,10 @@ void AgentManager::continueStartup()
     ensureAutoStart( info );
 
   // register the real service name once everything is up an running
-  if ( !QDBusConnection::sessionBus().registerService( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE) ) ) {
+  if ( !QDBusConnection::sessionBus().registerService( AkDBus::serviceName(AkDBus::Control) ) ) {
     // besides a race with an older Akonadi server I have no idea how we could possibly get here...
-    akFatal() << "Unable to register service as" << AKONADI_DBUS_CONTROL_SERVICE << "despite having the lock. Error was:" << QDBusConnection::sessionBus().lastError().message();
+    akFatal() << "Unable to register service as" << AkDBus::serviceName(AkDBus::Control)
+              << "despite having the lock. Error was:" << QDBusConnection::sessionBus().lastError().message();
   }
   akDebug() << "Akonadi server is now operational.";
 }
@@ -139,14 +148,14 @@ void AgentManager::cleanup()
 
   mStorageController->setCrashPolicy( ProcessControl::StopOnCrash );
   org::freedesktop::Akonadi::Server *serverIface =
-    new org::freedesktop::Akonadi::Server( QLatin1String("org.freedesktop.Akonadi"), QLatin1String("/Server"),
+    new org::freedesktop::Akonadi::Server( AkDBus::serviceName(AkDBus::Server), QLatin1String("/Server"),
                                            QDBusConnection::sessionBus(), this );
   serverIface->quit();
 
   if ( mAgentServer ) {
     mAgentServer->setCrashPolicy( ProcessControl::StopOnCrash );
     org::freedesktop::Akonadi::AgentServer *agentServerIface =
-        new org::freedesktop::Akonadi::AgentServer( QLatin1String("org.freedesktop.Akonadi.AgentServer"),
+        new org::freedesktop::Akonadi::AgentServer( AkDBus::serviceName(AkDBus::AgentServer),
                                                     QLatin1String("/AgentServer"), QDBusConnection::sessionBus(), this );
     agentServerIface->quit();
   }
@@ -275,12 +284,12 @@ void AgentManager::removeAgentInstance( const QString &identifier )
 
   save();
 
-  org::freedesktop::Akonadi::ResourceManager resmanager( QLatin1String( "org.freedesktop.Akonadi" ), QLatin1String( "/ResourceManager" ), QDBusConnection::sessionBus(), this );
+  org::freedesktop::Akonadi::ResourceManager resmanager( AkDBus::serviceName(AkDBus::Server), QLatin1String( "/ResourceManager" ), QDBusConnection::sessionBus(), this );
   resmanager.removeResourceInstance( instance->identifier() );
 
   // Kill the preprocessor instance, if any.
   org::freedesktop::Akonadi::PreprocessorManager preProcessorManager(
-      QLatin1String( "org.freedesktop.Akonadi" ),
+      AkDBus::serviceName(AkDBus::Server),
       QLatin1String( "/PreprocessorManager" ),
       QDBusConnection::sessionBus(),
       this
@@ -511,25 +520,12 @@ QStringList AgentManager::pluginInfoPathList()
   return Akonadi::XdgBaseDirs::findAllResourceDirs( "data", QLatin1String( "akonadi/agents" ) );
 }
 
-QString AgentManager::configPath( bool writeable )
-{
-  const QString configFile =
-    Akonadi::XdgBaseDirs::findResourceFile( "config", QLatin1String( "akonadi/agentsrc" ) );
-
-  if ( !writeable && !configFile.isEmpty() )
-    return configFile;
-
-  const QString configDir = Akonadi::XdgBaseDirs::saveDir( "config", QLatin1String("akonadi") );
-
-  return configDir + QLatin1String( "/agentsrc" );
-}
-
 void AgentManager::load()
 {
-  org::freedesktop::Akonadi::ResourceManager resmanager( QLatin1String( "org.freedesktop.Akonadi" ), QLatin1String( "/ResourceManager" ), QDBusConnection::sessionBus(), this );
+  org::freedesktop::Akonadi::ResourceManager resmanager( AkDBus::serviceName(AkDBus::Server), QLatin1String( "/ResourceManager" ), QDBusConnection::sessionBus(), this );
   const QStringList knownResources = resmanager.resourceInstances();
 
-  QSettings file( configPath( false ), QSettings::IniFormat );
+  QSettings file( AkStandardDirs::agentConfigFile( Akonadi::XdgBaseDirs::ReadOnly ), QSettings::IniFormat );
   file.beginGroup( QLatin1String("Instances") );
   const QStringList entries = file.childGroups();
   for ( int i = 0; i < entries.count(); ++i ) {
@@ -569,7 +565,7 @@ void AgentManager::load()
 
 void AgentManager::save()
 {
-  QSettings file( configPath( true ), QSettings::IniFormat );
+  QSettings file( AkStandardDirs::agentConfigFile( Akonadi::XdgBaseDirs::WriteOnly ), QSettings::IniFormat );
 
   foreach ( const AgentType &info, mAgents )
     info.save( &file );
@@ -594,106 +590,110 @@ void AgentManager::serviceOwnerChanged( const QString &name, const QString&, con
 
   //qDebug() << "Service " << name << " owner changed from " << oldOwner << " to " << newOwner;
 
-  if ( (name == QLatin1String(AKONADI_DBUS_SERVER_SERVICE) || name == QLatin1String(AKONADI_DBUS_AGENTSERVER_SERVICE)) && !newOwner.isEmpty() ) {
-    if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_SERVER_SERVICE) )
-      && ( !mAgentServer || QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_AGENTSERVER_SERVICE) ) ) )
+  if ( (name == AkDBus::serviceName(AkDBus::Server) || name == AkDBus::serviceName(AkDBus::AgentServer)) && !newOwner.isEmpty() ) {
+    if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Server) )
+      && ( !mAgentServer || QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::AgentServer) ) ) )
     {
       // server is operational, start agents
       continueStartup();
     }
   }
 
-  if ( name.startsWith( QLatin1String( "org.freedesktop.Akonadi.Agent." ) ) ) {
+  AkDBus::AgentType agentType = AkDBus::Unknown;
+  const QString agentIdentifier = AkDBus::parseAgentServiceName( name, agentType );
+  switch (agentType) {
+    case AkDBus::Agent:
+    {
+      // An agent service went up or down
+      if ( newOwner.isEmpty() )
+        return; // It went down: we don't care here.
 
-    // An agent service went up or down
+      if ( !mAgentInstances.contains( agentIdentifier ) )
+        return;
 
-    if ( newOwner.isEmpty() )
-      return; // It went down: we don't care here.
+      const AgentInstance::Ptr instance = mAgentInstances.value( agentIdentifier );
+      const bool restarting = instance->hasAgentInterface();
+      if ( !instance->obtainAgentInterface() )
+        return;
 
-    const QString identifier = name.mid( 30 );
-    if ( !mAgentInstances.contains( identifier ) )
-      return;
+      if ( !restarting )
+        emit agentInstanceAdded( agentIdentifier );
 
-    const AgentInstance::Ptr instance = mAgentInstances.value( identifier );
-    const bool restarting = instance->hasAgentInterface();
-    if ( !instance->obtainAgentInterface() )
-      return;
-
-    if ( !restarting )
-      emit agentInstanceAdded( identifier );
-
-  } else if ( name.startsWith( QLatin1String( "org.freedesktop.Akonadi.Resource." ) ) ) {
-
-    // A resource service went up or down
-
-    if ( newOwner.isEmpty() )
-      return; // It went down: we don't care here.
-
-    const QString identifier = name.mid( 33 );
-    if ( !mAgentInstances.contains( identifier ) )
-      return;
-
-    mAgentInstances.value( identifier )->obtainResourceInterface();
-
-  } else if ( name.startsWith( QLatin1String( "org.freedesktop.Akonadi.Preprocessor." ) ) ) {
-
-    // A preprocessor service went up or down
-
-    // If the preprocessor is going up then the org.freedesktop.Akonadi.Agent.* interface
-    // should be already up (as it's registered before the preprocessor one).
-    // So if we don't know about the preprocessor as agent instance
-    // then it's not our preprocessor.
-
-    // If the preprocessor is going down then either the agent interface already
-    // went down (and it has been already unregistered on the manager side)
-    // or it's still registered as agent and WE have to unregister it.
-    // The order of interface deletions depends on Qt but we handle both cases.
-
-    // Check if we "know" about it.
-
-    const QString identifier = name.mid( 37 );
-
-    qDebug() << "Preprocessor " << identifier << " is going up or down...";
-
-    if ( !mAgentInstances.contains( identifier ) ) {
-      qDebug() << "But it isn't registered as agent... not mine (anymore?)";
-      return; // not our agent (?)
+      break;
     }
+    case AkDBus::Resource:
+    {
+      // A resource service went up or down
+      if ( newOwner.isEmpty() )
+        return; // It went down: we don't care here.
 
-    org::freedesktop::Akonadi::PreprocessorManager preProcessorManager(
-        QLatin1String( "org.freedesktop.Akonadi" ),
-        QLatin1String( "/PreprocessorManager" ),
-        QDBusConnection::sessionBus(),
-        this
-      );
+      if ( !mAgentInstances.contains( agentIdentifier ) )
+        return;
 
-    if ( !preProcessorManager.isValid() ) {
-      akError() << Q_FUNC_INFO <<"Could not connect to PreprocessorManager via D-Bus:" << preProcessorManager.lastError();
-    } else {
-      if ( newOwner.isEmpty() ) {
-        // The preprocessor went down. Unregister it on server side.
+      mAgentInstances.value( agentIdentifier )->obtainResourceInterface();
 
-        preProcessorManager.unregisterInstance( identifier );
+      break;
+    }
+    case AkDBus::Preprocessor:
+    {
+      // A preprocessor service went up or down
 
-      } else {
+      // If the preprocessor is going up then the org.freedesktop.Akonadi.Agent.* interface
+      // should be already up (as it's registered before the preprocessor one).
+      // So if we don't know about the preprocessor as agent instance
+      // then it's not our preprocessor.
 
-        // The preprocessor went up. Register it on server side.
+      // If the preprocessor is going down then either the agent interface already
+      // went down (and it has been already unregistered on the manager side)
+      // or it's still registered as agent and WE have to unregister it.
+      // The order of interface deletions depends on Qt but we handle both cases.
 
-        if ( !mAgentInstances.value( identifier )->obtainPreprocessorInterface() ) {
-          // Hm.. couldn't hook up its preprocessor interface..
-          // Make sure we don't have it in the preprocessor chain
-          qWarning() << "Couldn't obtain preprocessor interface for instance " << identifier;
+      // Check if we "know" about it.
+      qDebug() << "Preprocessor " << agentIdentifier << " is going up or down...";
 
-          preProcessorManager.unregisterInstance( identifier );
-          return;
-        }
-
-        qDebug() << "Registering preprocessor instance " << identifier;
-
-        // Add to the preprocessor chain
-        preProcessorManager.registerInstance( identifier );
+      if ( !mAgentInstances.contains( agentIdentifier ) ) {
+        qDebug() << "But it isn't registered as agent... not mine (anymore?)";
+        return; // not our agent (?)
       }
+
+      org::freedesktop::Akonadi::PreprocessorManager preProcessorManager(
+          AkDBus::serviceName(AkDBus::Server),
+          QLatin1String( "/PreprocessorManager" ),
+          QDBusConnection::sessionBus(),
+          this
+        );
+
+      if ( !preProcessorManager.isValid() ) {
+        akError() << Q_FUNC_INFO <<"Could not connect to PreprocessorManager via D-Bus:" << preProcessorManager.lastError();
+      } else {
+        if ( newOwner.isEmpty() ) {
+          // The preprocessor went down. Unregister it on server side.
+
+          preProcessorManager.unregisterInstance( agentIdentifier );
+
+        } else {
+
+          // The preprocessor went up. Register it on server side.
+
+          if ( !mAgentInstances.value( agentIdentifier )->obtainPreprocessorInterface() ) {
+            // Hm.. couldn't hook up its preprocessor interface..
+            // Make sure we don't have it in the preprocessor chain
+            qWarning() << "Couldn't obtain preprocessor interface for instance " << agentIdentifier;
+
+            preProcessorManager.unregisterInstance( agentIdentifier );
+            return;
+          }
+
+          qDebug() << "Registering preprocessor instance " << agentIdentifier;
+
+          // Add to the preprocessor chain
+          preProcessorManager.registerInstance( agentIdentifier );
+        }
+      }
+
+      break;
     }
+    default: break;
   }
 }
 
@@ -752,7 +752,7 @@ void AgentManager::ensureAutoStart( const AgentType &info )
   if ( !info.capabilities.contains( AgentType::CapabilityAutostart ) )
     return; // no an autostart agent
 
-  org::freedesktop::Akonadi::AgentServer agentServer( QLatin1String("org.freedesktop.Akonadi.AgentServer"),
+  org::freedesktop::Akonadi::AgentServer agentServer( AkDBus::serviceName(AkDBus::AgentServer),
                                                       QLatin1String("/AgentServer"), QDBusConnection::sessionBus(), this );
 
   if ( mAgentInstances.contains( info.identifier ) ||
@@ -788,7 +788,7 @@ void AgentManager::registerAgentAtServer( const QString &agentIdentifier, const
 {
   if ( type.capabilities.contains( AgentType::CapabilityResource ) ) {
     boost::scoped_ptr<org::freedesktop::Akonadi::ResourceManager> resmanager(
-      new org::freedesktop::Akonadi::ResourceManager( QLatin1String( "org.freedesktop.Akonadi" ),
+      new org::freedesktop::Akonadi::ResourceManager( AkDBus::serviceName(AkDBus::Server),
                                                       QLatin1String( "/ResourceManager" ),
                                                       QDBusConnection::sessionBus(), this ) );
     resmanager->addResourceInstance( agentIdentifier, type.capabilities );
