@@ -18,7 +18,9 @@
  ***************************************************************************/
 
 #include "processcontrol.h"
-#include "akdebug.h"
+
+#include <akapplication.h>
+#include <akdebug.h>
 
 #include <QtCore/QDebug>
 #include <QtCore/QTimer>
@@ -41,11 +43,19 @@ ProcessControl::ProcessControl( QObject *parent )
   : QObject( parent ), mFailedToStart( false ), mCrashCount( 0 ),
   mRestartOnceOnExit( false )
 {
-  connect( &mProcess, SIGNAL( error( QProcess::ProcessError ) ),
-           this, SLOT( slotError( QProcess::ProcessError ) ) );
-  connect( &mProcess, SIGNAL( finished( int, QProcess::ExitStatus ) ),
-           this, SLOT( slotFinished( int, QProcess::ExitStatus ) ) );
+  connect( &mProcess, SIGNAL(error(QProcess::ProcessError)),
+           this, SLOT(slotError(QProcess::ProcessError)) );
+  connect( &mProcess, SIGNAL(finished(int,QProcess::ExitStatus)),
+           this, SLOT(slotFinished(int,QProcess::ExitStatus)) );
   mProcess.setProcessChannelMode( QProcess::ForwardedChannels );
+
+  if ( !AkApplication::instanceIdentifier().isEmpty() ) {
+    QProcessEnvironment env = mProcess.processEnvironment();
+    if ( env.isEmpty() )
+      env = QProcessEnvironment::systemEnvironment();
+    env.insert( QLatin1String("AKONADI_INSTANCE"), AkApplication::instanceIdentifier() );
+    mProcess.setProcessEnvironment( env );
+  }
 }
 
 ProcessControl::~ProcessControl()
@@ -90,7 +100,7 @@ void ProcessControl::slotError( QProcess::ProcessError error )
       break;
   }
 
-  qDebug( "ProcessControl: Application '%s' stopped unexpected (%s)",
+  qDebug( "ProcessControl: Application '%s' stopped unexpectedly (%s)",
           qPrintable( mApplication ), qPrintable( mProcess.errorString() ) );
 }
 
@@ -107,7 +117,7 @@ void ProcessControl::slotFinished( int exitCode, QProcess::ExitStatus exitStatus
         if ( mFailedToStart ) {
           qDebug( "Application '%s' failed to start!", qPrintable( mApplication ) );
         } else {
-          qDebug( "Application '%s' crashed to often. Giving up!", qPrintable( mApplication ) );
+          qDebug( "Application '%s' crashed too often. Giving up!", qPrintable( mApplication ) );
         }
         mPolicy = StopOnCrash;
         emit unableToStart();
