@@ -20,10 +20,13 @@
 #include "akonadi.h"
 #include "akonadiconnection.h"
 #include "serveradaptor.h"
-#include "akdebug.h"
+#include <akdbus.h>
+#include <akdebug.h>
+#include <akstandarddirs.h>
 
 #include "cachecleaner.h"
 #include "intervalcheck.h"
+#include "storagejanitor.h"
 #include "storage/dbconfig.h"
 #include "storage/datastore.h"
 #include "notificationmanager.h"
@@ -71,15 +74,14 @@ AkonadiServer::AkonadiServer( QObject* parent )
 #endif
     , mCacheCleaner( 0 )
     , mIntervalChecker( 0 )
+    , mStorageJanitor( 0 )
     , mItemRetrievalThread( 0 )
     , mDatabaseProcess( 0 )
     , mAlreadyShutdown( false )
 {
-    const QString serverConfigFile = XdgBaseDirs::akonadiServerConfigFile( XdgBaseDirs::ReadWrite );
+    const QString serverConfigFile = AkStandardDirs::serverConfigFile( XdgBaseDirs::ReadWrite );
     QSettings settings( serverConfigFile, QSettings::IniFormat );
 
-    DbConfig::configuredDatabase()->init( settings );
-
     if ( DbConfig::configuredDatabase()->useInternalServer() )
       startDatabaseProcess();
     else
@@ -89,7 +91,7 @@ AkonadiServer::AkonadiServer( QObject* parent )
 
     s_instance = this;
 
-    const QString connectionSettingsFile = XdgBaseDirs::akonadiConnectionConfigFile( XdgBaseDirs::WriteOnly );
+    const QString connectionSettingsFile = AkStandardDirs::connectionConfigFile( XdgBaseDirs::WriteOnly );
     QSettings connectionSettings( connectionSettingsFile, QSettings::IniFormat );
 
 #ifdef Q_OS_WIN
@@ -139,7 +141,7 @@ AkonadiServer::AkonadiServer( QObject* parent )
     connectionSettings.setValue( QLatin1String( "Data/Method" ), QLatin1String( "NamedPipe" ) );
     connectionSettings.setValue( QLatin1String( "Data/NamedPipe" ), namedPipe );
 #else
-    const QString socketDir = Utils::preferredSocketDirectory( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi" ) ) );
+    const QString socketDir = Utils::preferredSocketDirectory( AkStandardDirs::saveDir( "data" ) );
     const QString socketFile = socketDir + QLatin1String( "/akonadiserver.socket" );
     unlink( socketFile.toUtf8().constData() );
     if ( !listen( socketFile ) )
@@ -176,6 +178,9 @@ AkonadiServer::AkonadiServer( QObject* parent )
     mIntervalChecker = new IntervalCheck( this );
     mIntervalChecker->start( QThread::IdlePriority );
 
+    mStorageJanitor = new StorageJanitorThread;
+    mStorageJanitor->start( QThread::IdlePriority );
+
     mItemRetrievalThread = new ItemRetrievalThread( this );
     mItemRetrievalThread->start( QThread::HighPriority );
 
@@ -197,12 +202,12 @@ AkonadiServer::AkonadiServer( QObject* parent )
       connectionSettings.setValue( QLatin1String( "DBUS/Address" ), QLatin1String( dbusAddress ) );
     }
 
-    QDBusServiceWatcher *watcher = new QDBusServiceWatcher( QLatin1String( AKONADI_DBUS_CONTROL_SERVICE ),
+    QDBusServiceWatcher *watcher = new QDBusServiceWatcher( AkDBus::serviceName(AkDBus::Control),
                                                             QDBusConnection::sessionBus(),
                                                             QDBusServiceWatcher::WatchForOwnerChange, this );
 
-    connect( watcher, SIGNAL( serviceOwnerChanged( const QString&, const QString&, const QString& ) ),
-             this, SLOT( serviceOwnerChanged( const QString&, const QString&, const QString& ) ) );
+    connect( watcher, SIGNAL(serviceOwnerChanged(QString,QString,QString)),
+             this, SLOT(serviceOwnerChanged(QString,QString,QString)) );
 
     // Unhide all the items that are actually hidden.
     // The hidden flag was probably left out after an (abrupt)
@@ -237,6 +242,7 @@ void AkonadiServer::quit()
     qDebug() << "terminating service threads";
     quitThread( mCacheCleaner );
     quitThread( mIntervalChecker );
+    quitThread( mStorageJanitor );
     quitThread( mItemRetrievalThread );
 
     delete mSearchManager;
@@ -256,12 +262,12 @@ void AkonadiServer::quit()
     qDebug() << "stopping db process";
     stopDatabaseProcess();
 
-    QSettings settings( XdgBaseDirs::akonadiServerConfigFile(), QSettings::IniFormat );
-    const QString connectionSettingsFile = XdgBaseDirs::akonadiConnectionConfigFile( XdgBaseDirs::WriteOnly );
+    QSettings settings( AkStandardDirs::serverConfigFile(), QSettings::IniFormat );
+    const QString connectionSettingsFile = AkStandardDirs::connectionConfigFile( XdgBaseDirs::WriteOnly );
 
 #ifndef Q_OS_WIN
     QSettings connectionSettings( connectionSettingsFile, QSettings::IniFormat );
-    const QString socketDir = Utils::preferredSocketDirectory( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi" ) ) );
+    const QString socketDir = Utils::preferredSocketDirectory( AkStandardDirs::saveDir( "data" ) );
 
     if ( !QDir::home().remove( socketDir + QLatin1String( "/akonadiserver.socket" ) ) )
         akError() << "Failed to remove Unix socket";
@@ -269,7 +275,7 @@ void AkonadiServer::quit()
     if ( !QDir::home().remove( connectionSettingsFile ) )
         akError() << "Failed to remove runtime connection config file";
 
-    QTimer::singleShot( 0, this, SLOT( doQuit() ) );
+    QTimer::singleShot( 0, this, SLOT(doQuit()) );
 }
 
 void AkonadiServer::doQuit()
@@ -286,7 +292,7 @@ void AkonadiServer::incomingConnection( quintptr socketDescriptor )
     if ( mAlreadyShutdown )
       return;
     QPointer<AkonadiConnection> thread = new AkonadiConnection( socketDescriptor, this );
-    connect( thread, SIGNAL( finished() ), thread, SLOT( deleteLater() ) );
+    connect( thread, SIGNAL(finished()), thread, SLOT(deleteLater()) );
     mConnections.append( thread );
     thread->start();
 }
@@ -305,8 +311,8 @@ void AkonadiServer::startDatabaseProcess()
     return;
 
   // create the database directories if they don't exists
-  XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/" ) );
-  XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/file_db_data" ) );
+  AkStandardDirs::saveDir( "data" );
+  AkStandardDirs::saveDir( "data", QLatin1String( "file_db_data" ) );
 
   DbConfig::configuredDatabase()->startInternalServer();
 }
