@@ -50,8 +50,8 @@ void CacheCleaner::cleanCache()
 {
   qint64 loopsWithExpiredItem = 0;
   // cycle over all collection
-  QList<Collection> collections = Collection::retrieveAll();
-  foreach ( Collection collection, collections ) {
+  const QVector<Collection> collections = Collection::retrieveAll();
+  Q_FOREACH ( /*sic!*/ Collection collection, collections ) {
     // determine active cache policy
     DataStore::self()->activeCachePolicy( collection );
 
