@@ -83,7 +83,7 @@ bool Akonadi::AkAppend::commit()
     if ( !mimeType.isValid() ) {
       MimeType m( QString::fromLatin1( mt ) );
       if ( !m.insert() )
-        return failureResponse( QString::fromLatin1( "Unable to create mimetype '%1'.").arg( QString::fromLatin1( mt ) ) );
+        return failureResponse( QByteArray( "Unable to create mimetype '") + mt + QByteArray( "'." ) );
       mimeType = m;
     }
 
@@ -178,7 +178,7 @@ bool AkAppend::parseStream()
   // by the database
 
   // parse part specification
-  QList<QPair<QByteArray, QPair<qint64, int> > > partSpecs;
+  QVector<QPair<QByteArray, QPair<qint64, int> > > partSpecs;
   QByteArray partName = "";
   qint64 partSize = -1;
   qint64 partSizes = 0;
@@ -225,6 +225,7 @@ bool AkAppend::parseStream()
     part.setData( allParts.mid( pos, partSpec.second.first ) );
     if ( partSpec.second.second != 0 )
       part.setVersion( partSpec.second.second );
+    part.setDatasize( partSpec.second.first );
     m_parts.append( part );
     pos += partSpec.second.first;
   }
