@@ -45,6 +45,15 @@
 
 using namespace Akonadi;
 
+static bool payloadChanged( const QSet<QByteArray> &changes )
+{
+  foreach ( const QByteArray &change, changes ) {
+    if ( change.startsWith( "PLD:" ) )
+      return true;
+  }
+  return false;
+}
+
 Store::Store( Scope::SelectionScope scope )
   : Handler()
   , mScope( scope )
@@ -135,12 +144,12 @@ bool Store::parseStream()
       if ( pimItems.at( i ).rev() != (int)mPreviousRevision )
         throw HandlerException( "[LLCONFLICT] Item was modified elsewhere, aborting STORE." );
     }
-    pimItems[ i ].setRev( pimItems[ i ].rev() + 1 );
   }
 
   QSet<QByteArray> changes;
   qint64 partSizes = 0;
   bool invalidateCache = false;
+  bool undirty = false;
   bool silent = false;
 
   // apply modifications
@@ -218,6 +227,7 @@ bool Store::parseStream()
     else if ( command == AKONADI_PARAM_UNDIRTY ) {
       m_streamParser->readString(); // read the 'false' string
       item.setDirty( false );
+      undirty = true;
     }
 
     else if ( command == AKONADI_PARAM_INVALIDATECACHE ) {
@@ -334,17 +344,31 @@ bool Store::parseStream()
   }
 
   QString datetime;
-  if ( !changes.isEmpty() ) {
+  if ( !changes.isEmpty() || invalidateCache || undirty ) {
+
     // update item size
     if ( pimItems.size() == 1 && (mSize > 0 || partSizes > 0) )
       pimItems.first().setSize( qMax( mSize, partSizes ) );
 
+    const bool onlyRemoteIdChanged = (changes.size() == 1 && changes.contains( AKONADI_PARAM_REMOTEID ));
+    const bool onlyRemoteRevisionChanged = (changes.size() == 1 && changes.contains( AKONADI_PARAM_REMOTEREVISION ));
+    const bool onlyRemoteIdAndRevisionChanged = (changes.size() == 2 && changes.contains( AKONADI_PARAM_REMOTEID )
+                                                                     && changes.contains( AKONADI_PARAM_REMOTEREVISION ));
+
+    // If only the remote id and/or the remote revision changed, we don't have to increase the REV,
+    // because these updates do not change the payload and can only be done by the owning resource -> no conflicts possible
+    const bool revisionNeedsUpdate = (!changes.isEmpty() && !onlyRemoteIdChanged && !onlyRemoteRevisionChanged && !onlyRemoteIdAndRevisionChanged);
+
     // run update query and prepare change notifications
     for ( int i = 0; i < pimItems.count(); ++i ) {
+
+      if ( revisionNeedsUpdate )
+        pimItems[ i ].setRev( pimItems[ i ].rev() + 1 );
+
       PimItem &item = pimItems[ i ];
       item.setDatetime( modificationtime );
       item.setAtime( modificationtime );
-      if ( !connection()->isOwnerResource( item ) )
+      if ( !connection()->isOwnerResource( item ) && payloadChanged( changes ) )
         item.setDirty( true );
       if ( !item.update() )
         throw HandlerException( "Unable to write item changes into the database" );
@@ -355,7 +379,8 @@ bool Store::parseStream()
         }
       }
 
-      store->notificationCollector()->itemChanged( item, changes );
+      if ( !changes.isEmpty() )
+        store->notificationCollector()->itemChanged( item, changes );
       if ( !silent )
         sendPimItemResponse( item );
     }
