@@ -40,8 +40,13 @@ namespace Akonadi {
  */
 class Subscribe : public Handler
 {
+  Q_OBJECT
   public:
-    bool handleLine( const QByteArray &line );
+    Subscribe( bool subscribe );
+    bool parseStream();
+
+  private:
+    bool mSubscribe;
 };
 
 }
