@@ -30,16 +30,6 @@
 
 using namespace Akonadi;
 
-QByteArray Akonadi::HandlerHelper::normalizeCollectionName(const QByteArray &name)
-{
-  QByteArray collectionByteArray = name;
-  if ( collectionByteArray.startsWith( '/' )  )
-    collectionByteArray = collectionByteArray.right( collectionByteArray.length() - 1 );
-  if ( collectionByteArray.endsWith( '/' ) )
-    collectionByteArray = collectionByteArray.left( collectionByteArray.length() - 1 );
-  return collectionByteArray;
-}
-
 Collection HandlerHelper::collectionFromIdOrName(const QByteArray & id)
 {
   // id is a number
@@ -49,9 +39,9 @@ Collection HandlerHelper::collectionFromIdOrName(const QByteArray & id)
     return Collection::retrieveById( collectionId );
 
   // id is a path
-  QString path = QString::fromUtf8( normalizeCollectionName( id ) ); // ### should be UTF-7 for real IMAP compatibility
+  QString path = QString::fromUtf8( id ); // ### should be UTF-7 for real IMAP compatibility
 
-  const QStringList pathParts = path.split( QLatin1Char('/') );
+  const QStringList pathParts = path.split( QLatin1Char('/'), QString::SkipEmptyParts );
   Collection col;
   foreach ( const QString &part, pathParts ) {
     SelectQueryBuilder<Collection> qb;
@@ -106,11 +96,6 @@ bool HandlerHelper::itemStatistics(const Akonadi::Collection& col, qint64& count
   return true;
 }
 
-int HandlerHelper::itemWithFlagCount(const Collection & col, const QString & flag)
-{
-  return itemWithFlagsCount( col, QStringList( flag ) );
-}
-
 int HandlerHelper::itemWithFlagsCount(const Akonadi::Collection& col, const QStringList& flags)
 {
   CountQueryBuilder qb( PimItem::tableName(), PimItem::idFullColumnName(), CountQueryBuilder::Distinct );
@@ -137,16 +122,6 @@ int HandlerHelper::itemCount(const Collection& col)
   return qb.result();
 }
 
-int HandlerHelper::itemWithoutFlagCount(const Collection & col, const QString & flag)
-{
-  // FIXME optimize me: use only one query or reuse previously done count
-  const int flagCount = itemWithFlagCount( col, flag );
-  const int totalCount = itemCount( col );
-  if ( totalCount < 0 || flagCount < 0 )
-    return -1;
-  return totalCount - flagCount;
-}
-
 int HandlerHelper::parseCachePolicy(const QByteArray & data, Collection & col, int start, bool *changed )
 {
   bool inheritChanged = false;
