@@ -37,11 +37,6 @@ class ImapStreamParser;
 class HandlerHelper
 {
   public:
-    /**
-      Removes leading and trailing delimiters.
-    */
-    static QByteArray normalizeCollectionName( const QByteArray &name );
-
     /**
       Returns the collection identified by the given id or path.
     */
@@ -72,16 +67,8 @@ class HandlerHelper
       which have a given flag set.
       @return -1 on error.
     */
-    static int itemWithFlagCount( const Collection &col, const QString &flag );
     static int itemWithFlagsCount( const Collection &col, const QStringList &flags );
 
-    /**
-      Returns the amount of existing items in the given collection
-      which have a given flag not set.
-      @return -1 on error
-    */
-    static int itemWithoutFlagCount( const Collection &col, const QString &flag );
-
     /**
       Parse cache policy and update the given Collection object accoordingly.
       @param changed Indicates whether or not the cache policy already available in @p col
