@@ -20,6 +20,7 @@
 
 #include "akonadi.h"
 #include "akapplication.h"
+#include "akdbus.h"
 #include "akdebug.h"
 #include "akcrash.h"
 
@@ -58,7 +59,7 @@ int main( int argc, char ** argv )
 #else
     Q_INIT_RESOURCE( akonadidb_mobile );
 #endif
-    AkApplication app( argc, argv );
+    AkCoreApplication app( argc, argv );
     app.setDescription( QLatin1String( "Akonadi Server\nDo not run manually, use 'akonadictl' instead to start/stop Akonadi." ) );
 
 #if !defined(NDEBUG) && !defined(_WIN32_WCE)
@@ -78,7 +79,7 @@ int main( int argc, char ** argv )
 #else
    if (
 #endif
-        !QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE_LOCK) ) ) {
+        !QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::ControlLock) ) ) {
      akError() << "Akonadi control process not found - aborting.";
      akFatal() << "If you started akonadiserver manually, try 'akonadictl start' instead.";
    }
@@ -86,7 +87,7 @@ int main( int argc, char ** argv )
     Akonadi::AkonadiServer::instance(); // trigger singleton creation
     AkonadiCrash::setShutdownMethod( shutdownHandler );
 
-    if ( !QDBusConnection::sessionBus().registerService( QLatin1String(AKONADI_DBUS_SERVER_SERVICE) ) )
+    if ( !QDBusConnection::sessionBus().registerService( AkDBus::serviceName(AkDBus::Server) ) )
       akFatal() << "Unable to connect to dbus service: " << QDBusConnection::sessionBus().lastError().message();
 
     const int result = app.exec();
