@@ -43,11 +43,11 @@ NepomukSearch::NepomukSearch( QObject* parent )
   : QObject( parent ), mSearchService( 0 )
 {
   mSearchService = new Nepomuk::Query::QueryServiceClient( this );
-  connect( mSearchService, SIGNAL(newEntries(QList<Nepomuk::Query::Result>)),
-           this, SLOT(idHitsAdded(QList<Nepomuk::Query::Result>)) );
-  mIdSearchService = new Nepomuk::Query::QueryServiceClient( this );
   connect( mSearchService, SIGNAL(newEntries(QList<Nepomuk::Query::Result>)),
            this, SLOT(hitsAdded(QList<Nepomuk::Query::Result>)) );
+  mIdSearchService = new Nepomuk::Query::QueryServiceClient( this );
+  connect( mIdSearchService, SIGNAL(newEntries(QList<Nepomuk::Query::Result>)),
+           this, SLOT(idHitsAdded(QList<Nepomuk::Query::Result>)) );
 }
 
 NepomukSearch::~NepomukSearch()
@@ -60,12 +60,19 @@ NepomukSearch::~NepomukSearch()
 
 QStringList NepomukSearch::search( const QString &query )
 {
+  //qDebug() << Q_FUNC_INFO << query;
   if ( !mSearchService ) {
     qWarning() << "Nepomuk search service not available!";
     return QStringList();
   }
 
-  if ( !mSearchService->blockingQuery( query ) ) {
+  // Insert a property request for the item Id. This should
+  // be part of the query already and extracted from that,
+  // but that doesn't seem to work at the moment, so be explicit.
+  QHash<QString, QString> encodedRps;
+  encodedRps.insert( QString::fromLatin1( "reqProp1" ), QUrl(QString::fromLatin1("http://akonadi-project.org/ontologies/aneo#akonadiItemId")).toString() );
+
+  if ( !mSearchService->blockingQuery( query, encodedRps ) ) {
     qWarning() << Q_FUNC_INFO << "Calling blockingQuery() failed!";
     return QStringList();
   }
@@ -73,6 +80,16 @@ QStringList NepomukSearch::search( const QString &query )
   return mMatchingUIDs.toList();
 }
 
+void NepomukSearch::addHit(const Nepomuk::Query::Result& result)
+{
+  const qint64 itemId = resultToId( result );
+
+  if ( itemId == -1 )
+    return;
+
+  mMatchingUIDs.insert( QString::number( itemId ) );
+}
+
 void NepomukSearch::hitsAdded( const QList<Nepomuk::Query::Result>& entries )
 {
   if ( !mSearchService ) {
@@ -80,26 +97,33 @@ void NepomukSearch::hitsAdded( const QList<Nepomuk::Query::Result>& entries )
     return;
   }
 
+  QList<Nepomuk::Query::Result> resultsWithoutIdProperty;
+
   Q_FOREACH( const Nepomuk::Query::Result &result, entries ) {
+    const Soprano::Node &property = result.requestProperty(QUrl( QLatin1String( "http://akonadi-project.org/ontologies/aneo#akonadiItemId" ) ));
+    if (!(property.isValid() && property.isLiteral() && property.literal().isString())) {
+      resultsWithoutIdProperty << result;
+    } else {
+      // for those results that already have a proper akonadi item id property,
+      // we can add matches right away
+      addHit(result);
+    }
+  }
+
+  // go fetch the akonadi item id property for those results that don't have them
+  Q_FOREACH( const Nepomuk::Query::Result &result, resultsWithoutIdProperty ) {
     QHash<QString, QString> encodedRps;
     //We do another query to get the akonadiItemId attribute (since it may not have been added to the original query)
     encodedRps.insert( QString::fromLatin1( "reqProp1" ), QUrl(QString::fromLatin1("http://akonadi-project.org/ontologies/aneo#akonadiItemId")).toString() );
-    mIdSearchService->blockingQuery(QString::fromLatin1("SELECT DISTINCT ?r ?reqProp1 WHERE { %1 a ?v2 . %1 <http://akonadi-project.org/ontologies/aneo#akonadiItemId> ?reqProp1 . } LIMIT 1").arg(result.resourceUri().toString()), encodedRps);
+    mIdSearchService->blockingQuery(QString::fromLatin1("SELECT DISTINCT ?r ?reqProp1 WHERE { <%1> a ?v2 . <%1> <http://akonadi-project.org/ontologies/aneo#akonadiItemId> ?reqProp1 . } LIMIT 1").arg(result.resourceUri().toString()), encodedRps);
   }
 }
 
 void NepomukSearch::idHitsAdded(const QList< Nepomuk::Query::Result >& entries)
 {
-
   Q_FOREACH( const Nepomuk::Query::Result &result, entries ) {
-    const qint64 itemId = resultToId( result );
-
-    if ( itemId == -1 )
-      continue;
-
-    mMatchingUIDs.insert( QString::number( itemId ) );
+    addHit(result);
   }
-
 }
 
 
