@@ -33,6 +33,7 @@
 #include "akdebug.h"
 #include "parthelper.h"
 #include "libs/protocol_p.h"
+#include "handler.h"
 
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDir>
@@ -95,6 +96,8 @@ void DataStore::open()
     debugLastDbError( "Cannot open database." );
   else
     qDebug() << "Database" << m_database.databaseName() << "opened using driver" << m_database.driverName();
+
+  DbConfig::configuredDatabase()->initSession( m_database );
 }
 
 void Akonadi::DataStore::close()
@@ -534,15 +537,19 @@ bool Akonadi::DataStore::removeCollectionAttribute(const Collection & col, const
   qb.addValueCondition( CollectionAttribute::collectionIdColumn(), Query::Equals, col.id() );
   qb.addValueCondition( CollectionAttribute::typeColumn(), Query::Equals, key );
   if ( !qb.exec() )
-    return false;
+    throw HandlerException( "Unable to query for collection attribute" );
 
-  foreach ( CollectionAttribute attr, qb.result() ) {
+  const QVector<CollectionAttribute> result = qb.result();
+  foreach ( CollectionAttribute attr, result ) {
     if ( !attr.remove() )
-      return false;
+      throw HandlerException( "Unable to remove collection attribute" );
   }
 
-  mNotificationCollector->collectionChanged( col, QList<QByteArray>() << key );
-  return true;
+  if (!result.isEmpty()) {
+    mNotificationCollector->collectionChanged( col, QList<QByteArray>() << key );
+    return true;
+  }
+  return false;
 }
 
 
