@@ -69,6 +69,9 @@ class DbConfigMysql : public DbConfig
      */
     virtual void stopInternalServer();
 
+    /// reimpl
+    virtual void initSession(const QSqlDatabase& database);
+
   private:
     QString mDatabaseName;
     QString mHostName;
