@@ -18,11 +18,12 @@
 */
 
 #include "dbconfigpostgresql.h"
-
-#include "../../libs/xdgbasedirs_p.h"
-#include "akdebug.h"
 #include "utils.h"
 
+#include <libs/xdgbasedirs_p.h>
+#include <akdebug.h>
+#include <akstandarddirs.h>
+
 #include <QtCore/QDir>
 #include <QtCore/QProcess>
 #include <QtSql/QSqlDriver>
@@ -49,14 +50,12 @@ QString DbConfigPostgresql::databaseName() const
 bool DbConfigPostgresql::init( QSettings &settings )
 {
   // determine default settings depending on the driver
-  QString defaultDbName;
   QString defaultHostName;
   QString defaultOptions;
   QString defaultServerPath;
   QString defaultInitDbPath;
   QString defaultCleanShutdownCommand;
 
-  defaultDbName = QLatin1String( "akonadi" );
 #ifndef Q_WS_WIN // We assume that PostgreSQL is running as service on Windows
   const bool defaultInternalServer = true;
 #else
@@ -65,22 +64,30 @@ bool DbConfigPostgresql::init( QSettings &settings )
 
   mInternalServer = settings.value( QLatin1String( "QPSQL/StartServer" ), defaultInternalServer ).toBool();
   if ( mInternalServer ) {
-    const QStringList postgresSearchPath = QStringList()
-      << QLatin1String( "/usr/sbin" )
-      << QLatin1String( "/usr/local/sbin" )
-      << QLatin1String( "/usr/lib/postgresql/8.4/bin" );
+    QStringList postgresSearchPath;
+
+#ifdef POSTGRES_PATH
+    const QString dir( QLatin1String( POSTGRES_PATH ) );
+    if( QDir( dir ).exists() )
+      postgresSearchPath << QLatin1String( POSTGRES_PATH );
+#endif
+    postgresSearchPath << QLatin1String( "/usr/sbin" )
+                       << QLatin1String( "/usr/local/sbin" )
+                       << QLatin1String( "/usr/lib/postgresql/8.4/bin" )
+                       << QLatin1String( "/usr/lib/postgresql/9.0/bin" )
+                       << QLatin1String( "/usr/lib/postgresql/9.1/bin" );
 
     defaultServerPath = XdgBaseDirs::findExecutableFile( QLatin1String( "pg_ctl" ), postgresSearchPath );
     defaultInitDbPath = XdgBaseDirs::findExecutableFile( QLatin1String( "initdb" ), postgresSearchPath );
-    defaultHostName = Utils::preferredSocketDirectory( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) ) );
-    defaultCleanShutdownCommand = QString::fromLatin1( "%1 stop -D%2" )
+    defaultHostName = Utils::preferredSocketDirectory( AkStandardDirs::saveDir( "data", QLatin1String( "db_misc" ) ) );
+    defaultCleanShutdownCommand = QString::fromLatin1( "%1 stop -D%2 -m fast" )
                                       .arg( defaultServerPath )
-                                      .arg( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_data" ) ) );
+                                      .arg( AkStandardDirs::saveDir( "data", QLatin1String( "db_data" ) ) );
   }
 
   // read settings for current driver
   settings.beginGroup( driverName() );
-  mDatabaseName = settings.value( QLatin1String( "Name" ), defaultDbName ).toString();
+  mDatabaseName = settings.value( QLatin1String( "Name" ), defaultDatabaseName() ).toString();
   mHostName = settings.value( QLatin1String( "Host" ), defaultHostName ).toString();
   mUserName = settings.value( QLatin1String( "User" ) ).toString();
   mPassword = settings.value( QLatin1String( "Password" ) ).toString();
@@ -130,8 +137,8 @@ bool DbConfigPostgresql::useInternalServer() const
 
 void DbConfigPostgresql::startInternalServer()
 {
-  const QString dataDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_data" ) );
-  const QString socketDir = Utils::preferredSocketDirectory( XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_misc" ) ) );
+  const QString dataDir = AkStandardDirs::saveDir( "data", QLatin1String( "db_data" ) );
+  const QString socketDir = Utils::preferredSocketDirectory( AkStandardDirs::saveDir( "data", QLatin1String( "db_misc" ) ) );
 
   if ( !QFile::exists( QString::fromLatin1( "%1/PG_VERSION" ).arg( dataDir ) ) ) {
     // postgres data directory not initialized yet, so call initdb on it
@@ -247,7 +254,7 @@ void DbConfigPostgresql::stopInternalServer()
   }
 
   // if pg_ctl couldn't terminate all the postgres processes, we have to kill the master one.
-  const QString dataDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/db_data" ) );
+  const QString dataDir = AkStandardDirs::saveDir( "data", QLatin1String( "db_data" ) );
   const QString pidFileName = QString::fromLatin1( "%1/postmaster.pid" ).arg( dataDir );
   QFile pidFile( pidFileName );
   if ( pidFile.open( QIODevice::ReadOnly ) ) {
