@@ -22,6 +22,7 @@
 #include "entities.h"
 #include "selectquerybuilder.h"
 #include "dbconfig.h"
+#include <akstandarddirs.h>
 #include <libs/xdgbasedirs_p.h>
 
 #include <QDir>
@@ -35,7 +36,7 @@ using namespace Akonadi;
 static QString fileNameForPart( Part *part )
 {
   Q_ASSERT( part->id() >= 0 );
-  const QString dataDir = XdgBaseDirs::saveDir( "data", QLatin1String( "akonadi/file_db_data" ) ) + QDir::separator();
+  const QString dataDir = AkStandardDirs::saveDir( "data", QLatin1String( "file_db_data" ) ) + QDir::separator();
   Q_ASSERT( dataDir != QDir::separator() );
   return dataDir + QString::number( part->id() );
 }
@@ -159,6 +160,7 @@ bool PartHelper::remove( const QString &column, const QVariant &value )
   SelectQueryBuilder<Part> builder;
   builder.addValueCondition( column, Query::Equals, value );
   builder.addValueCondition( Part::externalColumn(), Query::Equals, true );
+  builder.addValueCondition( Part::dataColumn(), Query::IsNot, QVariant() );
   if ( !builder.exec() ) {
 //      qDebug() << "Error selecting records to be deleted from table"
 //          << Part::tableName() << builder.query().lastError().text();
