@@ -25,12 +25,14 @@
 #include <QBuffer>
 
 #include "imapstreamparser.h"
+#include <aktest.h>
 
 Q_DECLARE_METATYPE( QList<QByteArray> )
 Q_DECLARE_METATYPE( QList<int> )
 
 using namespace Akonadi;
 
+#if 0
 QString akBacktrace()
 {
   QString s;
@@ -59,8 +61,9 @@ QString akBacktrace()
 
   return s;
 }
+#endif
 
-QTEST_MAIN( ImapStreamParserTest )
+AKTEST_MAIN( ImapStreamParserTest )
 
 
 void ImapStreamParserTest::testParseQuotedString( )
